import { RequestSerializer, SerdeContext, SerdeFunctions, SerializeMiddleware } from "@smithy/types";
import type { V1OrV2Endpoint } from "./serdePlugin";
/**
 * @internal
 */
export declare const serializerMiddleware: <Input extends object = any, Output extends object = any, CommandSerdeContext extends SerdeContext = any>(options: V1OrV2Endpoint & SerdeFunctions, serializer: RequestSerializer<any, CommandSerdeContext>) => SerializeMiddleware<Input, Output>;
